@@ -1,13 +1,13 @@
+import importlib
 import inspect
 import os
 import traceback
-import importlib
 
-from conan.internal.cache.home_paths import HomePaths
-from conan.internal.subsystems import deduce_subsystem, subsystem_path
-from conan.internal.errors import conanfile_exception_formatter
 from conan.errors import ConanException
-from conan.internal.util.files import save, mkdir, chdir
+from conan.internal.cache.home_paths import HomePaths
+from conan.internal.errors import conanfile_exception_formatter
+from conan.internal.util.files import mkdir, chdir
+
 
 _generators = {"CMakeToolchain": "conan.tools.cmake",
                "CMakeDeps": "conan.tools.cmake",
@@ -93,31 +93,31 @@ def write_generators(conanfile, hook_manager, home_folder, envs_generation=None)
         if gen not in old_generators:
             old_generators.append(gen)
     conanfile.generators = []
-    try:
-        for generator_name in old_generators:
-            if isinstance(generator_name, str):
-                global_generator = global_generators.get(generator_name)
-                generator_class = global_generator or _get_generator_class(generator_name)
-            else:
-                generator_class = generator_name
-                generator_name = generator_class.__name__
-            if generator_class:
-                try:
-                    generator = generator_class(conanfile)
-                    mkdir(new_gen_folder)
-                    conanfile.output.info(f"Generator '{generator_name}' calling 'generate()'")
-                    with chdir(new_gen_folder):
-                        generator.generate()
-                    continue
-                except Exception as e:
-                    # When a generator fails, it is very useful to have the whole stacktrace
-                    if not isinstance(e, ConanException):
-                        conanfile.output.error(traceback.format_exc(), error_type="exception")
-                    raise ConanException(f"Error in generator '{generator_name}': {str(e)}") from e
-    finally:
-        # restore the generators attribute, so it can raise
-        # if the user tries to instantiate a generator already present in generators
-        conanfile.generators = old_generators
+
+    for generator_name in old_generators:
+        if isinstance(generator_name, str):
+            global_generator = global_generators.get(generator_name)
+            generator_class = global_generator or _get_generator_class(generator_name)
+        else:
+            generator_class = generator_name
+            generator_name = generator_class.__name__
+        assert generator_class
+        try:
+            generator = generator_class(conanfile)
+            mkdir(new_gen_folder)
+            conanfile.output.info(f"Generator '{generator_name}' calling 'generate()'")
+            with chdir(new_gen_folder):
+                generator.generate()
+        except Exception as e:
+            # When a generator fails, it is very useful to have the whole stacktrace
+            if not isinstance(e, ConanException):
+                conanfile.output.error(traceback.format_exc(), error_type="exception")
+            raise ConanException(f"Error in generator '{generator_name}': {str(e)}") from e
+
+    # restore the generators attribute, so it can raise
+    # if the user tries to instantiate a generator already present in generators
+    conanfile.generators = old_generators
+
     if hasattr(conanfile, "generate"):
         conanfile.output.highlight("Calling generate()")
         conanfile.output.info(f"Generators folder: {new_gen_folder}")
@@ -141,8 +141,8 @@ def write_generators(conanfile, hook_manager, home_folder, envs_generation=None)
                 env = VirtualRunEnv(conanfile)
                 env.generate()
 
-    _generate_aggregated_env(conanfile)
-
+    from conan.tools.env.environment import generate_aggregated_env
+    generate_aggregated_env(conanfile)
     hook_manager.execute("post_generate", conanfile=conanfile)
 
 
@@ -172,78 +172,6 @@ def _receive_generators(conanfile):
             conanfile.generators = build_req.generator_info + list(conanfile.generators)
 
 
-def _generate_aggregated_env(conanfile):
-
-    def deactivates(filenames):
-        # FIXME: Probably the order needs to be reversed
-        result = []
-        for s in reversed(filenames):
-            folder, f = os.path.split(s)
-            result.append(os.path.join(folder, "deactivate_{}".format(f)))
-        return result
-
-    generated = []
-    for group, env_scripts in conanfile.env_scripts.items():
-        subsystem = deduce_subsystem(conanfile, group)
-        bats = []
-        shs = []
-        ps1s = []
-        for env_script in env_scripts:
-            path = os.path.join(conanfile.generators_folder, env_script)
-            # Only the .bat and .ps1 are made relative to current script
-            if env_script.endswith(".bat"):
-                path = os.path.relpath(path, conanfile.generators_folder)
-                bats.append("%~dp0/"+path)
-            elif env_script.endswith(".sh"):
-                shs.append(subsystem_path(subsystem, path))
-            elif env_script.endswith(".ps1"):
-                path = os.path.relpath(path, conanfile.generators_folder)
-                # This $PSScriptRoot uses the current script directory
-                ps1s.append("$PSScriptRoot/"+path)
-        if shs:
-            def sh_content(files):
-                return ". " + " && . ".join('"{}"'.format(s) for s in files)
-            filename = "conan{}.sh".format(group)
-            generated.append(filename)
-            save(os.path.join(conanfile.generators_folder, filename), sh_content(shs))
-            save(os.path.join(conanfile.generators_folder, "deactivate_{}".format(filename)),
-                 sh_content(deactivates(shs)))
-        if bats:
-            def bat_content(files):
-                return "\r\n".join(["@echo off"] + ['call "{}"'.format(b) for b in files])
-            filename = "conan{}.bat".format(group)
-            generated.append(filename)
-            save(os.path.join(conanfile.generators_folder, filename), bat_content(bats))
-            save(os.path.join(conanfile.generators_folder, "deactivate_{}".format(filename)),
-                 bat_content(deactivates(bats)))
-        if ps1s:
-            def ps1_content(files):
-                return "\r\n".join(['& "{}"'.format(b) for b in files])
-            filename = "conan{}.ps1".format(group)
-            generated.append(filename)
-            save(os.path.join(conanfile.generators_folder, filename), ps1_content(ps1s))
-            save(os.path.join(conanfile.generators_folder, "deactivate_{}".format(filename)),
-                 ps1_content(deactivates(ps1s)))
-    if generated:
-        conanfile.output.highlight("Generating aggregated env files")
-        conanfile.output.info(f"Generated aggregated env files: {generated}")
-
-
-def relativize_paths(conanfile, placeholder):
-    abs_base_path = conanfile.folders._base_generators
-    if not abs_base_path or not os.path.isabs(abs_base_path):
-        return None, None
-    abs_base_path = os.path.join(abs_base_path, "")  # For the trailing / to dissambiguate matches
-    generators_folder = conanfile.generators_folder
-    try:
-        rel_path = os.path.relpath(abs_base_path, generators_folder)
-    except ValueError:  # In case the unit in Windows is different, path cannot be made relative
-        return None, None
-    new_path = placeholder if rel_path == "." else os.path.join(placeholder, rel_path)
-    new_path = os.path.join(new_path, "")  # For the trailing / to dissambiguate matches
-    return abs_base_path, new_path
-
-
 def relativize_path(path, conanfile, placeholder, normalize=True):
     """
     relative path from the "generators_folder" to "path", asuming the root file, like
