@@ -60,16 +60,6 @@ class RecipesDBTable(BaseDbTable):
         with self.db_connection() as conn:
             conn.execute(query)
 
-    def update_lru(self, refs):
-        params = [(str(ref), ref.revision) for ref in refs]
-        where_clause = f"{self.columns.reference} = ? AND {self.columns.rrev} = ?"
-        lru = timestamp_now()
-        query = f"UPDATE {self.table_name} " \
-                f"SET {self.columns.lru} = '{lru}' " \
-                f"WHERE {where_clause};"
-        with self.db_connection() as conn:
-            conn.executemany(query, params)
-
     def remove(self, ref: RecipeReference):
         where_clause = self._where_clause(ref)
         query = f"DELETE FROM {self.table_name} " \
