@@ -1,13 +1,14 @@
 import filecmp
 import os
 import shutil
+import fnmatch
 
 from conan.internal.cache.home_paths import HomePaths
 from conan.api.output import ConanOutput
-from conans.client.loader import load_python_file
+from conan.internal.loader import load_python_file
 from conan.internal.errors import conanfile_exception_formatter
 from conan.errors import ConanException
-from conans.util.files import rmdir, mkdir
+from conan.internal.util.files import rmdir, mkdir, save
 
 
 def _find_deployer(d, cache_deploy_folder):
@@ -37,13 +38,15 @@ def _find_deployer(d, cache_deploy_folder):
         return _load(cache_path)
     builtin_deploy = {"full_deploy.py": full_deploy,
                       "direct_deploy.py": direct_deploy,
-                      "runtime_deploy.py": runtime_deploy}.get(d)
+                      "runtime_deploy.py": runtime_deploy,
+                      "cyclone_1.6.py": cyclonedx_1_6,
+                      "cyclone_1.4.py": cyclonedx_1_4}.get(d)
     if builtin_deploy is not None:
         return builtin_deploy
     raise ConanException(f"Cannot find deployer '{d}'")
 
 
-def do_deploys(conan_api, graph, deploy, deploy_package, deploy_folder):
+def do_deploys(home_folder, graph, deploy, deploy_package, deploy_folder):
     try:
         mkdir(deploy_folder)
     except Exception as e:
@@ -57,7 +60,7 @@ def do_deploys(conan_api, graph, deploy, deploy_package, deploy_folder):
             conanfile = node.conanfile
             if not conanfile.ref:  # virtual or conanfile.txt, can't have deployer
                 continue
-            consumer = conanfile._conan_is_consumer
+            consumer = conanfile._conan_is_consumer  # noqa
             if any(conanfile.ref.matches(p, consumer) for p in excluded):
                 continue
             if not any(conanfile.ref.matches(p, consumer) for p in included):
@@ -68,7 +71,7 @@ def do_deploys(conan_api, graph, deploy, deploy_package, deploy_folder):
                 with conanfile_exception_formatter(conanfile, "deploy"):
                     conanfile.deploy()
     # Handle the deploys
-    cache = HomePaths(conan_api.cache_folder)
+    cache = HomePaths(home_folder)
     for d in deploy or []:
         deployer = _find_deployer(d, cache.deployers_path)
         # IMPORTANT: Use always kwargs to not break if it changes in the future
@@ -99,6 +102,9 @@ def full_deploy(graph, output_folder):
 def runtime_deploy(graph, output_folder):
     """
     Deploy all the shared libraries and the executables of the dependencies in a flat directory.
+
+    It preserves symlinks in case the configuration tools.deployer:symlinks is True.
+    It preserves the directory structure when having subfolders
     """
     conanfile = graph.root.conanfile
     output = ConanOutput(scope="runtime_deploy")
@@ -125,15 +131,29 @@ def runtime_deploy(graph, output_folder):
             if not os.path.isdir(libdir):
                 output.warning(f"{dep.ref} {libdir} does not exist")
                 continue
-            count += _flatten_directory(dep, libdir, output_folder, symlinks, [".dylib", ".so"])
+            count += _flatten_directory(dep, libdir, output_folder, symlinks, [".dylib*", ".so*"])
 
         output.info(f"Copied {count} files from {dep.ref}")
     conanfile.output.success(f"Runtime deployed to folder: {output_folder}")
 
 
+def cyclonedx_1_4(graph, output_folder):
+    from conan.tools.sbom import cyclonedx_1_4
+    import json
+    sbom = cyclonedx_1_4(graph.root.conanfile)
+    save(os.path.join(output_folder, "sbom-cyclonedx-1.4.json"), json.dumps(sbom, indent=2))
+
+
+def cyclonedx_1_6(graph, output_folder):
+    from conan.tools.sbom import cyclonedx_1_6
+    import json
+    sbom = cyclonedx_1_6(graph.root.conanfile)
+    save(os.path.join(output_folder, "sbom-cyclonedx-1.6.json"), json.dumps(sbom, indent=2))
+
+
 def _flatten_directory(dep, src_dir, output_dir, symlinks, extension_filter=None):
     """
-    Copy all the files from the source directory in a flat output directory.
+    Copy all the files from the source directory in a flat output directory, respecting subfolders.
     An optional string, named extension_filter, can be set to copy only the files with
     the listed extensions.
     """
@@ -141,12 +161,20 @@ def _flatten_directory(dep, src_dir, output_dir, symlinks, extension_filter=None
 
     output = ConanOutput(scope="runtime_deploy")
     for src_dirpath, _, src_filenames in os.walk(src_dir, followlinks=symlinks):
+        rel_path = os.path.relpath(src_dirpath, src_dir)
         for src_filename in src_filenames:
-            if extension_filter and not any(src_filename.endswith(ext) for ext in extension_filter):
+            if extension_filter and not any(fnmatch.fnmatch(src_filename, f'*{ext}') for ext in extension_filter):
                 continue
 
             src_filepath = os.path.join(src_dirpath, src_filename)
-            dest_filepath = os.path.join(output_dir, src_filename)
+            dest_filepath = os.path.join(output_dir, rel_path, src_filename)
+
+            if not symlinks and os.path.islink(src_filepath):
+                continue
+
+            if not os.path.exists(os.path.dirname(dest_filepath)):
+                os.makedirs(os.path.dirname(dest_filepath))
+
             if os.path.exists(dest_filepath):
                 if filecmp.cmp(src_filepath, dest_filepath):  # Be efficient, do not copy
                     output.verbose(f"{dest_filepath} exists with same contents, skipping copy")
@@ -156,7 +184,9 @@ def _flatten_directory(dep, src_dir, output_dir, symlinks, extension_filter=None
 
             try:
                 file_count += 1
-                shutil.copy2(src_filepath, dest_filepath, follow_symlinks=symlinks)
+                # INFO: When follow_symlinks is false, and src is a symbolic link, it tries to
+                # copy all metadata from the src symbolic link to the newly created dst link
+                shutil.copy2(src_filepath, dest_filepath, follow_symlinks=not symlinks)
                 output.verbose(f"Copied {src_filepath} into {output_dir}")
             except Exception as e:
                 if "WinError 1314" in str(e):
