@@ -18,8 +18,8 @@ def write_cmake_presets(conanfile, toolchain_file, generator, cache_variables,
                         user_presets_path=None, preset_prefix=None, buildenv=None, runenv=None,
                         cmake_executable=None, absolute_paths=None):
     preset_path, preset_data = _CMakePresets.generate(conanfile, toolchain_file, generator,
-                                                      cache_variables, preset_prefix, buildenv, runenv,
-                                                      cmake_executable, absolute_paths)
+                                                      cache_variables, preset_prefix, buildenv,
+                                                      runenv, cmake_executable, absolute_paths)
     _IncludingPresets.generate(conanfile, preset_path, user_presets_path, preset_prefix, preset_data,
                                absolute_paths)
 
@@ -28,8 +28,8 @@ class _CMakePresets:
     """ Conan generated main CMakePresets.json inside the generators_folder
     """
     @staticmethod
-    def generate(conanfile, toolchain_file, generator, cache_variables, preset_prefix, buildenv, runenv,
-                 cmake_executable, absolute_paths):
+    def generate(conanfile, toolchain_file, generator, cache_variables, preset_prefix, buildenv,
+                 runenv, cmake_executable, absolute_paths):
         toolchain_file = os.path.abspath(os.path.join(conanfile.generators_folder, toolchain_file))
         if not absolute_paths:
             try:  # Make it relative to the build dir if possible
@@ -104,7 +104,8 @@ class _CMakePresets:
         """
         multiconfig = is_multi_configuration(generator)
         conf = _CMakePresets._configure_preset(conanfile, generator, cache_variables, toolchain_file,
-                                               multiconfig, preset_prefix, buildenv, cmake_executable)
+                                               multiconfig, preset_prefix, buildenv,
+                                               cmake_executable)
         build = _CMakePresets._build_preset_fields(conanfile, multiconfig, preset_prefix)
         test = _CMakePresets._test_preset_fields(conanfile, multiconfig, preset_prefix, runenv)
         ret = {"version": 3,
@@ -174,17 +175,11 @@ class _CMakePresets:
         if conanfile.build_folder:
             # If we are installing a ref: "conan install <ref>", we don't have build_folder, because
             # we don't even have a conanfile with a `layout()` to determine the build folder.
-            # If we install a local conanfile: "conan install ." with a layout(), it will be available.
+            # If we install a local conanfile "conan install ." with a layout(), it will be available
             ret["binaryDir"] = conanfile.build_folder
 
         def _format_val(val):
-            return f'"{val}"' if type(val) == str and " " in val else f"{val}"
-
-        # https://github.com/conan-io/conan/pull/12034#issuecomment-1253776285
-        cache_variables_info = " ".join(
-            [f"-D{var}={_format_val(value)}" for var, value in cache_variables.items()])
-        add_toolchain_cache = f"-DCMAKE_TOOLCHAIN_FILE={toolchain_file} " \
-            if "CMAKE_TOOLCHAIN_FILE" not in cache_variables_info else ""
+            return f'"{val}"' if type(val) is str and " " in val else f"{val}"
 
         try:
             is_consumer = conanfile._conan_node.recipe == RECIPE_CONSUMER and \
@@ -192,10 +187,15 @@ class _CMakePresets:
         except:
             is_consumer = False
         if is_consumer:
+            # https://github.com/conan-io/conan/pull/12034#issuecomment-1253776285
+            vars_tip = " ".join([f"-D{k}={_format_val(v)}" for k, v in cache_variables.items()])
+            tc_tip = f"-DCMAKE_TOOLCHAIN_FILE=<output_folder>/{toolchain_file} " \
+                if "CMAKE_TOOLCHAIN_FILE" not in vars_tip else ""
+
             msg = textwrap.dedent(f"""\
                 CMakeToolchain: Preset '{name}' added to CMakePresets.json.
                     (cmake>=3.23) cmake --preset {name}
-                    (cmake<3.23) cmake <path> -G {_format_val(generator)} {add_toolchain_cache} {cache_variables_info}""")
+                    (cmake<3.23) cmake <path> -G {_format_val(generator)} {tc_tip} {vars_tip}""")
             conanfile.output.info(msg, fg=Color.CYAN)
         return ret
 
@@ -216,12 +216,16 @@ class _CMakePresets:
     def _build_preset_fields(conanfile, multiconfig, preset_prefix):
         ret = _CMakePresets._common_preset_fields(conanfile, multiconfig, preset_prefix)
         build_preset_jobs = build_jobs(conanfile)
-        ret["jobs"] = build_preset_jobs
+        if build_preset_jobs:
+            ret["jobs"] = build_preset_jobs
         return ret
 
     @staticmethod
     def _test_preset_fields(conanfile, multiconfig, preset_prefix, runenv):
         ret = _CMakePresets._common_preset_fields(conanfile, multiconfig, preset_prefix)
+        build_preset_jobs = build_jobs(conanfile)
+        if build_preset_jobs:
+            ret.setdefault("execution", {})["jobs"] = build_preset_jobs
         if runenv:
             ret["environment"] = runenv
         return ret
