@@ -11,7 +11,7 @@ from conan.errors import ConanException
 from conan.internal.api.install.generators import relativize_path
 from conan.internal.model.dependencies import get_transitive_requires
 from conan.tools.microsoft.visual import msvc_platform_from_arch
-from conans.util.files import load, save
+from conan.internal.util.files import load, save
 
 VALID_LIB_EXTENSIONS = (".so", ".lib", ".a", ".dylib", ".bc")
 
@@ -157,9 +157,17 @@ class MSBuildDeps:
         :return: varfile content
         """
 
-        def add_valid_ext(libname):
+        def add_valid_ext(libname, libdirs=None):
             ext = os.path.splitext(libname)[1]
-            return '%s;' % libname if ext in VALID_LIB_EXTENSIONS else '%s.lib;' % libname
+            if ext in VALID_LIB_EXTENSIONS:
+                return f"{libname};"
+
+            lib_name = f"{libname}.lib"
+            if libdirs and not any(lib_name in os.listdir(d) for d in libdirs if os.path.isdir(d)):
+                meson_name = f"lib{libname}.a"
+                if any(meson_name in os.listdir(d) for d in libdirs if os.path.isdir(d)):
+                    lib_name = meson_name
+            return f"{lib_name};"
 
         pkg_placeholder = "$(Conan{}RootFolder)".format(name)
 
@@ -191,7 +199,7 @@ class MSBuildDeps:
         res_dirs = join_paths(cpp_info.resdirs)
         include_dirs = join_paths(cpp_info.includedirs)
         lib_dirs = join_paths(cpp_info.libdirs)
-        libs = "".join([add_valid_ext(lib) for lib in cpp_info.libs])
+        libs = "".join([add_valid_ext(lib, cpp_info.libdirs) for lib in cpp_info.libs])
         # TODO: Missing objects
         system_libs = "".join([add_valid_ext(sys_dep) for sys_dep in cpp_info.system_libs])
         definitions = "".join("%s;" % d for d in cpp_info.defines)
@@ -341,7 +349,7 @@ class MSBuildDeps:
                         except KeyError:  # The transitive dep might have been skipped
                             required = None
                         if required:  # The transitive dep might have been skipped
-                            required_name = required.ref.name
+                            required_name = self._dep_name(required, build)
                             public_deps.append(required_name if required_pkg == required_comp
                                                else "{}_{}".format(required_name, required_comp))
                     else:  # Points to a component of same package
